## START: Set by rpmautospec
## (rpmautospec version 0.6.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Test data is stored in a separate git repository. We should always use the
# latest commit at the time of the release we are packaging.
%global stf_commit 7cc512a7c60361ebe1baf54991d7905efdc62aa0
%global stf_url https://github.com/fastfloat/supplemental_test_files

# Build and run exhaustive tests?
#
# These really do take a long time—at least an hour on the fastest machines,
# and over ten hours on s390x (affected also by limited parallelism). Some
# tests cover the entire single-precision domain, about four billion inputs.
# Still, we can finish before we hit any timeouts, and running the exhaustive
# tests brings peace of mind.
%bcond exhaustive 1

Name:           fast_float
Summary:        Fast & exact implementation of C++ from_chars for number types
Version:        6.1.1
Release:        %autorelease

URL:            https://github.com/fastfloat/fast_float
# README.md:
#   Licensed under either of Apache License, Version 2.0 or MIT license or
#   BOOST license.
# Supplemental test files (Source1) are Apache-2.0 only (no MIT option); they
# do not contribute to the binary RPMs.
License:        Apache-2.0 OR MIT OR BSL-1.0

Source0:        %{url}/archive/v%{version}/fast_float-%{version}.tar.gz
Source1:        %{stf_url}/archive/%{stf_commit}/supplemental_test_files-%{stf_commit}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
# Our choice; the default make backend should work just as well
BuildRequires:  ninja-build

BuildRequires:  doctest-devel
# Doctest is header-only, so we must BR:
BuildRequires:  doctest-static

# No compiled binaries are installed, so this would be empty.
%global debug_package %{nil}

%global common_description %{expand:
The fast_float library provides fast header-only implementations for the C++
from_chars functions for float and double types as well as integer types. These
functions convert ASCII strings representing decimal values (e.g., 1.3e10) into
binary types. We provide exact rounding (including round to even). In our
experience, these fast_float functions many times faster than comparable
number-parsing functions from existing C++ standard libraries.}

%description %{common_description}


%package devel
Summary:        %{summary}

BuildArch:      noarch

# Header-only library
Provides:       fast_float-static = %{version}-%{release}

%description devel %{common_description}


%prep
%autosetup
%setup -q -T -D -b 1
# Compiling with -Werror makes sense for upstream CI, but is excessively strict
# for downstream builds across a variety of compiler versions.
sed -r -i 's/-Werror//' tests/CMakeLists.txt


%build
# Partially emulate the activity of FetchContent_Declare() in
# tests/CMakeLists.txt so that we can run the tests offline.
mkdir -p '%{_vpath_builddir}/_deps'
ln -s "${PWD}/../supplemental_test_files-%{stf_commit}/" \
    '%{_vpath_builddir}/_deps/supplemental_test_files-src'

%cmake \
    -GNinja \
    -DFETCHCONTENT_FULLY_DISCONNECTED:BOOL=ON \
    -DSYSTEM_DOCTEST:BOOL=ON \
    -DFASTFLOAT_TEST:BOOL=ON \
    -DFASTFLOAT_EXHAUSTIVE:BOOL=%{?with_exhaustive:ON}%{?!with_exhaustive:OFF}
%cmake_build


%install
%cmake_install


%check
%ctest


%files devel
%license LICENSE-APACHE
%license LICENSE-MIT
%license LICENSE-BOOST
%doc AUTHORS
%doc CONTRIBUTORS
%doc README.md

%{_includedir}/fast_float/

%{_datadir}/cmake/FastFloat/


%changelog
## START: Generated by rpmautospec
* Mon Mar 18 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.1.1-1
- Update to 6.1.1 (close RHBZ#2270000)

* Tue Jan 30 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.1.0-1
- Update to 6.1.0 (close RHBZ#2260990)

* Wed Jan 24 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Dec 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 6.0.0-1
- Update to 6.0.0 (close RHBZ#2254687)

* Wed Nov 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.3.0-1
- Update to 5.3.0 (close RHBZ#2249761)

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sun Jul 02 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.2.0-1
- Update to 5.2.0 (close RHBZ#2213937)

* Sun Jun 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.0.0-2
- Use new (rpm 4.17.1+) bcond style

* Fri May 26 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 5.0.0-1
- Update to 5.0.0 (close RHBZ#2210325)
- License changes from (Apache-2.0 OR MIT) to (Apache-2.0 OR MIT OR
  BSL-1.0)

* Thu May 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.0-2
- Drop unnecessary manual dependency on cmake-filesystem

* Mon Apr 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.0-1
- Update to 4.0.0 (close RHBZ#2183568)

* Thu Mar 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.11.0-1
- Update to 3.11.0 (close RHBZ#2182344)

* Tue Mar 07 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.1-1
- Update to 3.10.1 (close RHBZ#2175980)

* Wed Feb 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.0-1
- Update to 3.10.0 (close RHBZ#2167538)

* Sat Jan 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.0-1
- Update to 3.9.0 (close RHBZ#2162158)

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.8.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Dec 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.8.1-2
- Indicate dirs. in files list with trailing slashes

* Sun Nov 27 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.8.1-1
- Update to 3.8.1 (close RHBZ#2148670)

* Fri Nov 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.8.0-1
- Update to 3.8.0 (close RHBZ#2148328)

* Thu Nov 17 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.0-1
- Update to 3.7.0 (close RHBZ#2143469)

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.0-1
- Update to 3.6.0 (close RHBZ#2140130)

* Sat Aug 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.1-1
- Update to 3.5.1 (close RHBZ#2115912)

* Mon Aug 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.0-9
- Update License field to SPDX

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Apr 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.0-7
- Drop “forge” macros, which are not doing much here

* Sat Mar 05 2022 Vitaly Zaitsev <vitaly@easycoding.org> - 3.4.0-6
- Export CMake targets as architecture independent.

* Tue Mar 01 2022 Vitaly Zaitsev <vitaly@easycoding.org> - 3.4.0-5
- Fixed CMake configs installation. Fixes RHBZ#2059643.

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.0-3
- Let the -devel package be noarch

* Thu Dec 09 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.0-2
- Stop meddling with install path for .cmake files

* Wed Dec 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.0-1
- Update to 3.4.0 (close RHBZ#2027907)

* Tue Sep 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.2.0-1
- Update to 3.2.0 (close RHBZ#2006183)

* Thu Sep 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.1.0-1
- Update to 3.1.0 (close RHBZ#2004552)

* Tue Sep 14 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.0.0-1
- Update to 3.0.0

* Wed Aug 04 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-1
- Fix version number

* Wed Aug 04 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-6
- Update to 2.0.0 (closes RHBZ#1989768)

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jul 11 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-3
- Drop EPEL8 support from Fedora branch

* Sat Jul 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-2
- BR: doctest-static now that it is available

* Mon Jun 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-1
- Update to 1.1.2
- Drop fast_float-1.1.1-system-doctest.patch; now merged upstream
- Add EPEL8 support
- Do not compile tests with -Werror

* Mon Jun 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.1-1
- Initial package

## END: Generated by rpmautospec
